@@ -1,6 +1,6 @@
 #include <QApplication>
 #include <QWidget>
-#include <QtCore/QEvent>
+#include <QEvent>
 #include <QCheckBox>
 
 #include "kprogressdialog.h"
@@ -30,7 +30,7 @@ private:
 
     int steps;
 
-    void timerEvent(QTimerEvent *) Q_DECL_OVERRIDE;
+    void timerEvent(QTimerEvent *) override;
 };
 
 void MyWidget::timerEvent(QTimerEvent *)
